rai\_toolbox.mushin.MetricsCallback
===================================

.. currentmodule:: rai_toolbox.mushin

.. autoclass:: MetricsCallback

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~MetricsCallback.__init__
   
